Index: sys/kern/kern_exec.c
===================================================================
RCS file: /cvsroot/src/sys/kern/kern_exec.c,v
retrieving revision 1.360
diff -u -r1.360 kern_exec.c
--- sys/kern/kern_exec.c	20 Apr 2013 22:28:58 -0000	1.360
+++ sys/kern/kern_exec.c	9 Jun 2013 00:30:11 -0000
@@ -126,15 +126,15 @@
 /*
  * DTrace SDT provider definitions
  */
-SDT_PROBE_DEFINE(proc,,,exec, 
+SDT_PROBE_DEFINE(proc,,,exec,exec,
 	    "char *", NULL,
 	    NULL, NULL, NULL, NULL,
 	    NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,exec_success, 
+SDT_PROBE_DEFINE(proc,,,exec_success,exec-success, 
 	    "char *", NULL,
 	    NULL, NULL, NULL, NULL,
 	    NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,exec_failure, 
+SDT_PROBE_DEFINE(proc,,,exec_failure,exec-failure, 
 	    "int", NULL,
 	    NULL, NULL, NULL, NULL,
 	    NULL, NULL, NULL, NULL);
Index: sys/kern/kern_exit.c
===================================================================
RCS file: /cvsroot/src/sys/kern/kern_exit.c,v
retrieving revision 1.242
diff -u -r1.242 kern_exit.c
--- sys/kern/kern_exit.c	27 Sep 2012 20:43:15 -0000	1.242
+++ sys/kern/kern_exit.c	9 Jun 2013 00:30:11 -0000
@@ -123,7 +123,7 @@
 /*
  * DTrace SDT provider definitions
  */
-SDT_PROBE_DEFINE(proc,,,exit, 
+SDT_PROBE_DEFINE(proc,,,exit,exit,
 	    "int", NULL, 		/* reason */
 	    NULL, NULL, NULL, NULL,
 	    NULL, NULL, NULL, NULL);
Index: sys/kern/kern_fork.c
===================================================================
RCS file: /cvsroot/src/sys/kern/kern_fork.c,v
retrieving revision 1.191
diff -u -r1.191 kern_fork.c
--- sys/kern/kern_fork.c	27 Jul 2012 20:52:49 -0000	1.191
+++ sys/kern/kern_fork.c	9 Jun 2013 00:30:11 -0000
@@ -98,7 +98,7 @@
 /*
  * DTrace SDT provider definitions
  */
-SDT_PROBE_DEFINE(proc,,,create,
+SDT_PROBE_DEFINE(proc,,,create,create,
 	    "struct proc *", NULL,	/* new process */
 	    "struct proc *", NULL,	/* parent process */
 	    "int", NULL,		/* flags */
Index: sys/kern/kern_lwp.c
===================================================================
RCS file: /cvsroot/src/sys/kern/kern_lwp.c,v
retrieving revision 1.174
diff -u -r1.174 kern_lwp.c
--- sys/kern/kern_lwp.c	16 Dec 2012 22:21:03 -0000	1.174
+++ sys/kern/kern_lwp.c	9 Jun 2013 00:30:11 -0000
@@ -251,15 +251,15 @@
 static void		lwp_dtor(void *, void *);
 
 /* DTrace proc provider probes */
-SDT_PROBE_DEFINE(proc,,,lwp_create,
+SDT_PROBE_DEFINE(proc,,,lwp_create,lwp-create,
 	"struct lwp *", NULL,
 	NULL, NULL, NULL, NULL,
 	NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,lwp_start,
+SDT_PROBE_DEFINE(proc,,,lwp_start,lwp-start,
 	"struct lwp *", NULL,
 	NULL, NULL, NULL, NULL,
 	NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,lwp_exit,
+SDT_PROBE_DEFINE(proc,,,lwp_exit,lwp-exit,
 	"struct lwp *", NULL,
 	NULL, NULL, NULL, NULL,
 	NULL, NULL, NULL, NULL);
Index: sys/kern/kern_sig.c
===================================================================
RCS file: /cvsroot/src/sys/kern/kern_sig.c,v
retrieving revision 1.317
diff -u -r1.317 kern_sig.c
--- sys/kern/kern_sig.c	19 Feb 2012 21:06:53 -0000	1.317
+++ sys/kern/kern_sig.c	9 Jun 2013 00:30:11 -0000
@@ -131,21 +131,21 @@
 /*
  * DTrace SDT provider definitions
  */
-SDT_PROBE_DEFINE(proc,,,signal_send, 
+SDT_PROBE_DEFINE(proc,,,signal_send,signal-send,
 	    "struct lwp *", NULL,	/* target thread */
 	    "struct proc *", NULL,	/* target process */
 	    "int", NULL, 		/* signal */
 	    NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,signal_discard, 
+SDT_PROBE_DEFINE(proc,,,signal_discard,signal-discard,
 	    "struct lwp *", NULL,	/* target thread */
 	    "struct proc *", NULL,	/* target process */
 	    "int", NULL, 		/* signal */
 	    NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,signal_clear, 
+SDT_PROBE_DEFINE(proc,,,signal_clear,signal-clear,
 	    "int", NULL,		/* signal */
 	    NULL, NULL, NULL, NULL,
 	    NULL, NULL, NULL, NULL);
-SDT_PROBE_DEFINE(proc,,,signal_handle, 
+SDT_PROBE_DEFINE(proc,,,signal_handle,signal-handle,
 	    "int", NULL,		/* signal */
 	    "ksiginfo_t *", NULL,
 	    "void (*)(void)", NULL,	/* handler address */
Index: sys/sys/sdt.h
===================================================================
RCS file: /cvsroot/src/sys/sys/sdt.h,v
retrieving revision 1.2
diff -u -r1.2 sdt.h
--- sys/sys/sdt.h	8 Dec 2011 22:27:36 -0000	1.2
+++ sys/sys/sdt.h	9 Jun 2013 00:30:11 -0000
@@ -78,7 +78,7 @@
 
 #ifdef KDTRACE_HOOKS
 /*
  * SDT_PROBE_DEFINE(prov, mod, func, name,
  *		    arg0, argx0, arg1, argx1,
  *		    arg2, argx2, arg3, argx3, arg4, argx4)
  *
@@ -86,6 +86,7 @@
  * 	mod	- module name
  * 	func	- function name
  * 	name	- probe name
+ * 	sname	- probe name as exposed to userland
  * 	arg0 - arg4, argument types as strings, or NULL.
  * 	argx0 - argx4, translation types for arg0 - arg4
  *
@@ -97,11 +98,11 @@
  *	This is used in the target module to define probes to be used.
  *	The translation type should be set to NULL if not used.
  */
-#define SDT_PROBE_DEFINE(prov, mod, func, name, \
+#define SDT_PROBE_DEFINE(prov, mod, func, name, sname, \
 	    arg0, argx0, arg1, argx1, arg2, argx2, \
 	    arg3, argx3, arg4, argx4) \
     	sdt_probe_t SDT_NAME(prov, mod, func, name) = { \
-	    0, 0, 0, #prov, #mod, #func, #name, \
+	    0, 0, 0, #prov, #mod, #func, #sname, \
 	    { arg0, arg1, arg2, arg3, arg4 }, \
 	    { NULL, NULL, NULL, NULL, NULL } \
 	}
@@ -118,7 +119,7 @@
 		    (uintptr_t)(arg3), (uintptr_t)(arg4)); \
 	}
 #else
-#define SDT_PROBE_DEFINE(prov, mod, func, name, \
+#define SDT_PROBE_DEFINE(prov, mod, func, name, sname, \
 	    arg0, argx0, arg1, argx1, arg2, argx2, \
 	    arg3, argx3, arg4, argx4)
 #define SDT_PROBE_DECLARE(prov, mod, func, name)
@@ -78,7 +78,7 @@
 #ifdef KDTRACE_HOOKS
 /*
- * SDT_PROBE_DEFINE(prov, mod, func, name,
+ * SDT_PROBE_DEFINE(prov, mod, func, name, sname,
  *		    arg0, argx0, arg1, argx1,
  *		    arg2, argx2, arg3, argx3, arg4, argx4)
